.. _tutorials:

=========
Tutorials
=========


Tutorials are the best place to start for anyone new to SymPy or one of
SymPy's features.

:ref:`Introductory Tutorial <intro-tutorial>`
=============================================

If you are new to SymPy, start here.

.. toctree::
   :hidden:

   intro-tutorial/index.rst
